@@ -53,6 +53,9 @@ module Rouge
           groups Keyword::Declaration, Text
           push :property
         end
+        rule %r'(return|continue|break|this|super)(@#{name})?\b' do
+          groups Keyword, Name::Decorator
+        end
         rule %r'\bfun\b', Keyword
         rule %r'\b(?:#{keywords.join('|')})\b', Keyword
         rule %r'^\s*\[.*?\]', Name::Attribute
@@ -62,15 +65,25 @@ module Rouge
         rule %r'/[*].*[*]/', Comment::Multiline # single line block comment
         rule %r'/[*].*', Comment::Multiline, :comment # multiline block comment
         rule %r'\n', Text
+        rule %r'(::)(class)' do
+          groups Operator, Keyword
+        end
         rule %r'::|!!|\?[:.]', Operator
         rule %r"(\.\.)", Operator
+        # Number literals
+        decDigits = %r"([0-9][0-9_]*[0-9])|[0-9]"
+        exponent = %r"[eE][+-]?(#{decDigits})"
+        double = %r"((#{decDigits})?\.#{decDigits}(#{exponent})?)|(#{decDigits}#{exponent})"
+        rule %r"(#{double}[fF]?)|(#{decDigits}[fF])", Num::Float
+        rule %r"0[bB]([01][01_]*[01]|[01])[uU]?L?", Num::Bin
+        rule %r"0[xX]([0-9a-fA-F][0-9a-fA-F_]*[0-9a-fA-F]|[0-9a-fA-F])[uU]?L?", Num::Hex
+        rule %r"(([1-9][0-9_]*[0-9])|[0-9])[uU]?L?", Num::Integer
         rule %r'[~!%^&*()+=|\[\]:;,.<>/?-]', Punctuation
         rule %r'[{}]', Punctuation
         rule %r'@"(""|[^"])*"'m, Str
         rule %r'""".*?"""'m, Str
         rule %r'"(\\\\|\\"|[^"\n])*["\n]'m, Str
         rule %r"'\\.'|'[^\\]'", Str::Char
-        rule %r"[0-9](\.[0-9]+)?([eE][+-][0-9]+)?[flFL]?|0[xX][0-9a-fA-F]+[Ll]?", Num
         rule %r'(@#{class_name})', Name::Decorator
         rule %r'(#{class_name})(<)' do
           groups Name::Class, Punctuation
@@ -78,6 +91,7 @@ module Rouge
         end
         rule class_name, Name::Class
         rule %r'(#{name})(?=\s*[({])', Name::Function
+        rule %r'(#{name})@', Name::Decorator # label
         rule name, Name
       end
 
@@ -101,12 +115,15 @@ module Rouge
       state :generic_parameters do
         rule class_name, Name::Class
         rule %r'(<)', Punctuation, :generic_parameters
-        rule %r'(,)', Punctuation
+        rule %r'(reified|out|in)', Keyword
+        rule %r'([,:.?])', Punctuation
         rule %r'(\s+)', Text
         rule %r'(>)', Punctuation, :pop!
       end
 
       state :property do
+        rule %r'(<)', Punctuation, :generic_parameters
+        rule %r'(\s+)', Text
         rule name, Name::Property, :pop!
       end
 
@@ -118,9 +135,10 @@ module Rouge
       end
 
       state :comment do
-        rule %r'\s*/[*].*', Comment::Multiline, :comment
-        rule %r'.*[*]/', Comment::Multiline, :pop!
-        rule %r'.*', Comment::Multiline
+        rule %r'/[*]', Comment::Multiline, :comment
+        rule %r'[*]/', Comment::Multiline, :pop!
+        rule %r'[^/*]+', Comment::Multiline
+        rule %r'[/*]', Comment::Multiline
       end
     end
   end
