@@ -42,7 +42,7 @@ module Rouge
         rule %r/%([rqswQWxiI])?([^\w\s])/ do |m|
           open = Regexp.escape(m[2])
           close = Regexp.escape(delimiter_map[m[2]] || m[2])
-          interp = /[rQWxI]/ === m[1]
+          interp = /[rQWxI]/ === m[1] || !m[1]
           toktype = Str::Other
 
           puts "    open: #{open.inspect}" if @debug
@@ -170,8 +170,11 @@ module Rouge
         rule %r/0_?[0-7]+(?:_[0-7]+)*/, Num::Oct
         rule %r/0x[0-9A-Fa-f]+(?:_[0-9A-Fa-f]+)*/, Num::Hex
         rule %r/0b[01]+(?:_[01]+)*/, Num::Bin
-        rule %r/\d+\.\d+(e[\+\-]?\d+)?/, Num::Float
-        rule %r/[\d]+(?:_\d+)*/, Num::Integer
+
+        decimal = %r/[\d]+(?:_\d+)*/
+        exp = %r/e[+-]?\d+/i
+        rule %r/#{decimal}(?:\.#{decimal}#{exp}?|#{exp})/, Num::Float
+        rule decimal, Num::Integer
 
         # names
         rule %r/@@[a-z_]\w*/i, Name::Variable::Class
@@ -185,6 +188,7 @@ module Rouge
 
         rule %r/(?:#{keywords.join('|')})(?=\W|$)/, Keyword, :expr_start
         rule %r/(?:#{keywords_pseudo.join('|')})\b/, Keyword::Pseudo, :expr_start
+        rule %r/(not|and|or)\b/, Operator::Word, :expr_start
 
         rule %r(
           (module)
@@ -306,6 +310,8 @@ module Rouge
 
       state :classname do
         rule %r/\s+/, Text
+        rule %r/\w+(::\w+)+/, Name::Class
+
         rule %r/\(/ do
           token Punctuation
           push :defexpr
@@ -324,7 +330,15 @@ module Rouge
       end
 
       state :ternary do
-        rule(/:(?!:)/) { token Punctuation; goto :expr_start }
+        rule %r/(:)(\s+)/ do
+          groups Punctuation, Text
+          goto :expr_start
+        end
+
+        rule %r/:(?![^#\n]*?[:\\])/ do
+          token Punctuation
+          goto :expr_start
+        end
 
         mixin :root
       end
@@ -361,7 +375,7 @@ module Rouge
       end
 
       state :method_call do
-        rule %r(/) do
+        rule %r(/|%) do
           token Operator
           goto :expr_start
         end
